"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Analytics = require("analytics-node");
class AnalyticsService {
    constructor({ writeKey, MockEffect }) {
        this.analytics = MockEffect ? MockEffect(writeKey) : new Analytics(writeKey);
    }
    track(payload) {
        try {
            const { analytics } = this;
            if ((payload.userId || payload.anonymousId) && payload.event) {
                analytics.track(payload);
            }
            else {
                console.error('AnalyticsService :: You must pass either an "anonymousId" or a "userId" and an "event" name.');
            }
        }
        catch (error) {
            console.error('AnalyticsService :: Error occurred when sending track-event to Segment');
            console.error('---->>--AnalyticsService--error----');
            console.error(error);
            console.error('----<<--AnalyticsService--error----');
        }
    }
    identify(payload) {
        try {
            const { analytics } = this;
            if (payload.userId || payload.anonymousId) {
                analytics.identify(payload);
            }
            else {
                console.error('AnalyticsService :: You must pass either an "anonymousId" or a "userId".');
            }
        }
        catch (error) {
            console.error('AnalyticsService :: Error occurred when sending identify-event to Segment');
            console.error('---->>--AnalyticsService--error----');
            console.error(error);
            console.error('----<<--AnalyticsService--error----');
        }
    }
    group(payload) {
        try {
            const { analytics } = this;
            if ((payload.userId || payload.anonymousId) && payload.groupId) {
                analytics.group(payload);
            }
            else {
                console.error('AnalyticsService :: You must pass either an "anonymousId" or a "userId" and a "groupId".');
            }
        }
        catch (error) {
            console.error('AnalyticsService :: Error occurred when sending group-event to Segment');
            console.error('---->>--AnalyticsService--error----');
            console.error(error);
            console.error('----<<--AnalyticsService--error----');
        }
    }
}
exports.default = AnalyticsService;
//# sourceMappingURL=index.js.map